# Generated by Django 2.0.7 on 2019-04-27 09:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0003_auto_20190427_0906'),
    ]

    operations = [
        migrations.AddField(
            model_name='errorrecord',
            name='referrer',
            field=models.CharField(blank=True, max_length=1024, verbose_name='Referrer'),
        )
    ]
