# Generated by Django 2.0.7 on 2019-04-27 09:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0002_auto_20190427_0832'),
    ]

    operations = [
        migrations.CreateModel(
            name='ErrorRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('path', models.CharField(db_index=True, max_length=1024, verbose_name='Path')),
                ('status_code', models.IntegerField(verbose_name='Status code')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Creation date')),
            ],
            options={
                'verbose_name': 'Error record',
                'verbose_name_plural': 'Error records',
            },
        )
    ]
