# Generated by Django 2.0.7 on 2019-04-27 08:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='RedirectRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('old_path', models.CharField(db_index=True, max_length=1024, unique=True, verbose_name='Old path')),
                ('new_path', models.CharField(max_length=1024, verbose_name='New path')),
            ],
            options={
                'verbose_name': 'Redirect record',
                'verbose_name_plural': 'Redirect records',
            },
        )
    ]
