# Generated by Django 2.0.7 on 2019-04-27 10:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0004_auto_20190427_0953'),
    ]

    operations = [
        migrations.AddField(
            model_name='errorrecord',
            name='method',
            field=models.CharField(default='get', max_length=100, verbose_name='Method'),
            preserve_default=False,
        )
    ]
