
{% extends 'base.html' %}

{% load i18n %}


{% block meta_title %}{{ code }} - {{ message }}{% endblock %}

{% block meta_robots %}noindex, nofollow{% endblock %}


{% block wrapper %}
    <div class="container p-t-30 p-b-30">

        <div class="text-center">
            <h1>{{ code }}</h1>

            <p>{{ message }}</p>

            <a href="{% url 'home' %}">
                <i class="fa fa-home"></i> {% trans 'Go to home page' %}
            </a>
        </div>

    </div>
{% endblock %}
